@@ -1,32 +1,19 @@
 /*
-   This file is part of the KDE libraries
-   Copyright (c) 2006, 2007 Thomas Braxton <kde.braxton@gmail.com>
-   Copyright (c) 1999-2000 Preston Brown <pbrown@kde.org>
-   Copyright (C) 1996-2000 Matthias Kalle Dalheimer <kalle@kde.org>
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2006, 2007 Thomas Braxton <kde.braxton@gmail.com>
+    SPDX-FileCopyrightText: 1999-2000 Preston Brown <pbrown@kde.org>
+    SPDX-FileCopyrightText: 1996-2000 Matthias Kalle Dalheimer <kalle@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KCONFIGDATA_H
 #define KCONFIGDATA_H
 
 #include <QByteArray>
-#include <QString>
-#include <QMap>
 #include <QDebug>
+#include <QMap>
+#include <QString>
 
 /**
  * map/dict/list config node entry.
@@ -35,55 +22,73 @@
 struct KEntry {
     /** Constructor. @internal */
     KEntry()
-        : mValue(), bDirty(false),
-          bGlobal(false), bImmutable(false), bDeleted(false), bExpand(false), bReverted(false),
-          bLocalizedCountry(false), bNotify(false) {}
+        : mValue()
+        , bDirty(false)
+        , bGlobal(false)
+        , bImmutable(false)
+        , bDeleted(false)
+        , bExpand(false)
+        , bReverted(false)
+        , bLocalizedCountry(false)
+        , bNotify(false)
+        , bOverridesGlobal(false)
+    {
+    }
     /** @internal */
     QByteArray mValue;
     /**
      * Must the entry be written back to disk?
      */
-    bool    bDirty : 1;
+    bool bDirty : 1;
     /**
      * Entry should be written to the global config file
      */
-    bool    bGlobal: 1;
+    bool bGlobal : 1;
     /**
      * Entry can not be modified.
      */
-    bool    bImmutable: 1;
+    bool bImmutable : 1;
     /**
      * Entry has been deleted.
      */
-    bool    bDeleted: 1;
+    bool bDeleted : 1;
     /**
      * Whether to apply dollar expansion or not.
      */
-    bool    bExpand: 1;
+    bool bExpand : 1;
     /**
      * Entry has been reverted to its default value (from a more global file).
      */
-    bool    bReverted: 1;
+    bool bReverted : 1;
     /**
      * Entry is for a localized key. If @c false the value references just language e.g. "de",
      * if @c true the value references language and country, e.g. "de_DE".
      **/
-    bool    bLocalizedCountry: 1;
+    bool bLocalizedCountry : 1;
 
-    bool     bNotify: 1;
+    bool bNotify : 1;
+
+    /**
+     * Entry will need to be written on a non global file even if it matches default value
+     */
+    bool bOverridesGlobal : 1;
 };
 
 // These operators are used to check whether an entry which is about
 // to be written equals the previous value. As such, this intentionally
 // omits the dirty/notify flag from the comparison.
-inline bool operator ==(const KEntry &k1, const KEntry &k2)
+inline bool operator==(const KEntry &k1, const KEntry &k2)
 {
-    return k1.bGlobal == k2.bGlobal && k1.bImmutable == k2.bImmutable
-           && k1.bDeleted == k2.bDeleted && k1.bExpand == k2.bExpand
-           && k1.mValue == k2.mValue;
+    /* clang-format off */
+    return k1.bGlobal == k2.bGlobal
+        && k1.bImmutable == k2.bImmutable
+        && k1.bDeleted == k2.bDeleted
+        && k1.bExpand == k2.bExpand
+        && k1.mValue == k2.mValue;
+    /* clang-format on */
 }
 
-inline bool operator !=(const KEntry &k1, const KEntry &k2)
+inline bool operator!=(const KEntry &k1, const KEntry &k2)
 {
     return !(k1 == k2);
 }
@@ -95,9 +100,12 @@ inline bool operator !=(const KEntry &k1, const KEntry &k2)
  */
 struct KEntryKey {
     /** Constructor. @internal */
-    KEntryKey(const QByteArray &_group = QByteArray(),
-              const QByteArray &_key = QByteArray(), bool isLocalized = false, bool isDefault = false)
-        : mGroup(_group), mKey(_key), bLocal(isLocalized), bDefault(isDefault), bRaw(false)
+    KEntryKey(const QByteArray &_group = QByteArray(), const QByteArray &_key = QByteArray(), bool isLocalized = false, bool isDefault = false)
+        : mGroup(_group)
+        , mKey(_key)
+        , bLocal(isLocalized)
+        , bDefault(isDefault)
+        , bRaw(false)
     {
         ;
     }
@@ -112,16 +120,16 @@ struct KEntryKey {
     /**
      * Entry is localised or not
      */
-    bool    bLocal  : 1;
+    bool bLocal : 1;
     /**
      * Entry indicates if this is a default value.
      */
-    bool    bDefault: 1;
+    bool bDefault : 1;
     /** @internal
      * Key is a raw unprocessed key.
      * @warning this should only be set during merging, never for normal use.
      */
-    bool    bRaw: 1;
+    bool bRaw : 1;
 };
 
 /**
@@ -129,14 +137,14 @@ struct KEntryKey {
  * non-localized, non-localized-default
  * @internal
  */
-inline bool operator <(const KEntryKey &k1, const KEntryKey &k2)
+inline bool operator<(const KEntryKey &k1, const KEntryKey &k2)
 {
-    int result = qstrcmp(k1.mGroup, k2.mGroup);
+    int result = qstrcmp(k1.mGroup.data(), k2.mGroup.data());
     if (result != 0) {
         return result < 0;
     }
 
-    result = qstrcmp(k1.mKey, k2.mKey);
+    result = qstrcmp(k1.mKey.data(), k2.mKey.data());
     if (result != 0) {
         return result < 0;
     }
@@ -162,7 +170,7 @@ class KEntryMap : public QMap<KEntryKey, KEntry>
 public:
     enum SearchFlag {
         SearchDefaults = 1,
-        SearchLocalized = 2
+        SearchLocalized = 2,
     };
     Q_DECLARE_FLAGS(SearchFlags, SearchFlag)
 
@@ -176,49 +184,47 @@ public:
         EntryLocalizedCountry = 64,
         EntryNotify = 128,
         EntryDefault = (SearchDefaults << 16),
-        EntryLocalized = (SearchLocalized << 16)
+        EntryLocalized = (SearchLocalized << 16),
     };
     Q_DECLARE_FLAGS(EntryOptions, EntryOption)
 
-    Iterator findExactEntry(const QByteArray &group, const QByteArray &key = QByteArray(),
-                            SearchFlags flags = SearchFlags());
+    Iterator findExactEntry(const QByteArray &group, const QByteArray &key = QByteArray(), SearchFlags flags = SearchFlags());
 
-    Iterator findEntry(const QByteArray &group, const QByteArray &key = QByteArray(),
-                       SearchFlags flags = SearchFlags());
+    Iterator findEntry(const QByteArray &group, const QByteArray &key = QByteArray(), SearchFlags flags = SearchFlags());
 
-    ConstIterator findEntry(const QByteArray &group, const QByteArray &key = QByteArray(),
-                            SearchFlags flags = SearchFlags()) const;
+    ConstIterator findEntry(const QByteArray &group, const QByteArray &key = QByteArray(), SearchFlags flags = SearchFlags()) const
+    {
+        return constFindEntry(group, key, flags);
+    }
+
+    ConstIterator constFindEntry(const QByteArray &group, const QByteArray &key = QByteArray(), SearchFlags flags = SearchFlags()) const;
 
     /**
      * Returns true if the entry gets dirtied or false in other case
      */
-    bool setEntry(const QByteArray &group, const QByteArray &key,
-                  const QByteArray &value, EntryOptions options);
+    bool setEntry(const QByteArray &group, const QByteArray &key, const QByteArray &value, EntryOptions options);
 
-    void setEntry(const QByteArray &group, const QByteArray &key,
-                  const QString &value, EntryOptions options)
+    void setEntry(const QByteArray &group, const QByteArray &key, const QString &value, EntryOptions options)
     {
         setEntry(group, key, value.toUtf8(), options);
     }
 
-    QString getEntry(const QByteArray &group, const QByteArray &key,
+    QString getEntry(const QByteArray &group,
+                     const QByteArray &key,
                      const QString &defaultValue = QString(),
                      SearchFlags flags = SearchFlags(),
                      bool *expand = nullptr) const;
 
-    bool hasEntry(const QByteArray &group, const QByteArray &key = QByteArray(),
-                  SearchFlags flags = SearchFlags()) const;
+    bool hasEntry(const QByteArray &group, const QByteArray &key = QByteArray(), SearchFlags flags = SearchFlags()) const;
 
     bool getEntryOption(const ConstIterator &it, EntryOption option) const;
-    bool getEntryOption(const QByteArray &group, const QByteArray &key,
-                        SearchFlags flags, EntryOption option) const
+    bool getEntryOption(const QByteArray &group, const QByteArray &key, SearchFlags flags, EntryOption option) const
     {
         return getEntryOption(findEntry(group, key, flags), option);
     }
 
     void setEntryOption(Iterator it, EntryOption option, bool bf);
-    void setEntryOption(const QByteArray &group, const QByteArray &key, SearchFlags flags,
-                        EntryOption option, bool bf)
+    void setEntryOption(const QByteArray &group, const QByteArray &key, SearchFlags flags, EntryOption option, bool bf)
     {
         setEntryOption(findEntry(group, key, flags), option, bf);
     }
