@@ -12,17 +12,12 @@
 */
 
 #include "KConfigHeaderGenerator.h"
-#include "KConfigCommonStructs.h"
 
-#include <QTextStream>
 #include <QDebug>
+#include <QTextStream>
 #include <iostream>
 
-KConfigHeaderGenerator::KConfigHeaderGenerator(
-    const QString &inputFile,
-    const QString &baseDir,
-    const KConfigParameters &cfg,
-    ParseResult &result)
+KConfigHeaderGenerator::KConfigHeaderGenerator(const QString &inputFile, const QString &baseDir, const KConfigParameters &cfg, ParseResult &result)
     : KConfigCodeGeneratorBase(inputFile, baseDir, baseDir + cfg.baseName + QLatin1Char('.') + cfg.headerExtension, cfg, result)
 {
 }
@@ -57,13 +52,8 @@ void KConfigHeaderGenerator::doClassDefinition()
     createConstructor();
     createDestructor();
 
-    for (auto *entry : parseResult.entries) {
-        const QString n = entry->name;
-        const QString t = entry->type;
-
-        const QString returnType = (cfg().useEnumTypes && t == QLatin1String("Enum"))
-            ? enumType(entry, cfg().globalEnums)
-            : cppType(t);
+    for (const auto *entry : qAsConst(parseResult.entries)) {
+        const QString returnType = (cfg().useEnumTypes && entry->type == QLatin1String("Enum")) ? enumType(entry, cfg().globalEnums) : cppType(entry->type);
 
         createSetters(entry);
         createProperties(entry, returnType);
@@ -84,14 +74,14 @@ void KConfigHeaderGenerator::doClassDefinition()
     }
 
     // Member variables
-    if (!cfg().memberVariables.isEmpty()
-        && cfg().memberVariables != QLatin1String("private")
+    if (!cfg().memberVariables.isEmpty() //
+        && cfg().memberVariables != QLatin1String("private") //
         && cfg().memberVariables != QLatin1String("dpointer")) {
         stream() << "  " << cfg().memberVariables << ":\n";
     }
 
     // Class Parameters
-    for (const auto &parameter : parseResult.parameters) {
+    for (const auto &parameter : qAsConst(parseResult.parameters)) {
         stream() << whitespace() << "" << cppType(parameter.type) << " mParam" << parameter.name << ";\n";
     }
 
@@ -136,7 +126,7 @@ void KConfigHeaderGenerator::startHeaderGuards()
 {
     const bool hasNamespace = !cfg().nameSpace.isEmpty();
     const QString namespaceName = QString(QString(cfg().nameSpace).replace(QLatin1String("::"), QLatin1String("_"))).toUpper();
-    const QString namespaceStr = hasNamespace ? namespaceName + QLatin1Char('_') : QStringLiteral("");
+    const QString namespaceStr = hasNamespace ? namespaceName + QLatin1Char('_') : QString{};
     const QString defineName = namespaceStr + cfg().className.toUpper() + QStringLiteral("_H");
 
     stream() << "#ifndef " << defineName << '\n';
@@ -211,14 +201,14 @@ void KConfigHeaderGenerator::implementEnums()
         return;
     }
 
-    for (const auto entry : parseResult.entries) {
+    for (const auto *entry : qAsConst(parseResult.entries)) {
         const CfgEntry::Choices &choices = entry->choices;
         const QStringList values = entry->paramValues;
 
         implementChoiceEnums(entry, choices);
         implementValueEnums(entry, values);
     }
-   stream() << '\n';
+    stream() << '\n';
 }
 
 void KConfigHeaderGenerator::createSignals()
@@ -245,32 +235,18 @@ void KConfigHeaderGenerator::createSignals()
     // a last comma, as it's valid c++.
     for (int i = 0, end = parseResult.signalList.size(); i < end; i++) {
         auto signal = parseResult.signalList.at(i);
-        stream() << whitespace() << "  " << signalEnumName(signal.name) << " = 0x"
-                 <<
-            #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                    hex
-            #else
-                    Qt::hex
-            #endif
-                 << val;
-        if (i != end-1) {
+        stream() << whitespace() << "  " << signalEnumName(signal.name) << " = 0x" << Qt::hex << val;
+        if (i != end - 1) {
             stream() << ",\n";
         }
 
         val <<= 1;
     }
     stream() << '\n';
-    stream() << whitespace() << "};"
-             <<
-            #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                    dec
-            #else
-                    Qt::dec
-            #endif
-             << "\n\n";
+    stream() << whitespace() << "};" << Qt::dec << "\n\n";
 
     stream() << "  Q_SIGNALS:";
-    for (const Signal &signal : parseResult.signalList) {
+    for (const Signal &signal : qAsConst(parseResult.signalList)) {
         stream() << '\n';
         if (!signal.label.isEmpty()) {
             stream() << whitespace() << "/**\n";
@@ -283,7 +259,7 @@ void KConfigHeaderGenerator::createSignals()
             Param argument = *it;
             QString type = param(argument.type);
             if (cfg().useEnumTypes && argument.type == QLatin1String("Enum")) {
-                for (auto *entry : parseResult.entries) {
+                for (const auto *entry : qAsConst(parseResult.entries)) {
                     if (entry->name == argument.name) {
                         type = enumType(entry, cfg().globalEnums);
                         break;
@@ -312,7 +288,7 @@ void KConfigHeaderGenerator::createDPointer()
 
     // use a private class for both member variables and items
     stream() << "  private:\n";
-    for (const auto &entry : parseResult.entries) {
+    for (const auto *entry : qAsConst(parseResult.entries)) {
         if (cfg().allDefaultGetters || cfg().defaultGetters.contains(entry->name)) {
             stream() << whitespace() << "";
             if (cfg().staticAccessors) {
@@ -348,7 +324,7 @@ void KConfigHeaderGenerator::createConstructor()
     }
 
     bool first = true;
-    for (const auto parameter : parseResult.parameters) {
+    for (const auto &parameter : qAsConst(parseResult.parameters)) {
         if (first) {
             first = false;
         } else {
@@ -380,7 +356,7 @@ void KConfigHeaderGenerator::createForwardDeclarations()
     }
 }
 
-void KConfigHeaderGenerator::createProperties(const CfgEntry *entry, const QString& returnType)
+void KConfigHeaderGenerator::createProperties(const CfgEntry *entry, const QString &returnType)
 {
     if (!cfg().generateProperties) {
         return;
@@ -393,8 +369,8 @@ void KConfigHeaderGenerator::createProperties(const CfgEntry *entry, const QStri
         stream() << " WRITE " << setFunction(entry->name);
         stream() << " NOTIFY " << signal;
 
-        //If we have the modified signal, we'll also need
-        //the changed signal as well
+        // If we have the modified signal, we'll also need
+        // the changed signal as well
         Signal s;
         s.name = signal;
         s.modify = true;
@@ -433,12 +409,10 @@ void KConfigHeaderGenerator::createSetters(const CfgEntry *entry)
 
     stream() << whitespace() << "void " << setFunction(entry->name) << "( ";
     if (!entry->param.isEmpty()) {
-        stream() <<cppType(entry->paramType) << " i, ";
+        stream() << cppType(entry->paramType) << " i, ";
     }
 
-    stream() << (cfg().useEnumTypes && entry->type == QLatin1String("Enum")
-        ? enumType(entry, cfg().globalEnums)
-        : param(entry->type));
+    stream() << (cfg().useEnumTypes && entry->type == QLatin1String("Enum") ? enumType(entry, cfg().globalEnums) : param(entry->type));
 
     stream() << " v )";
 
@@ -497,7 +471,7 @@ void KConfigHeaderGenerator::createImmutableGetters(const CfgEntry *entry)
     stream() << whitespace() << "";
     stream() << "bool " << immutableFunction(entry->name) << "(";
     if (!entry->param.isEmpty()) {
-        stream() << " " << cppType(entry->paramType)<< " i ";
+        stream() << " " << cppType(entry->paramType) << " i ";
     }
     stream() << ")" << Const();
     // function body inline only if not using dpointer
@@ -522,11 +496,9 @@ void KConfigHeaderGenerator::createItemAcessors(const CfgEntry *entry, const QSt
         return;
     }
     stream() << whitespace() << "/**\n";
-    stream() << whitespace() << "  Get Item object corresponding to " << entry->name << "()"
-        << '\n';
+    stream() << whitespace() << "  Get Item object corresponding to " << entry->name << "()" << '\n';
     stream() << whitespace() << "*/\n";
-    stream() << whitespace() << "Item" << itemType(entry->type) << " *"
-        << getFunction(entry->name) << "Item(";
+    stream() << whitespace() << "Item" << itemType(entry->type) << " *" << getFunction(entry->name) << "Item(";
     if (!entry->param.isEmpty()) {
         stream() << " " << cppType(entry->paramType) << " i ";
     }
@@ -546,7 +518,7 @@ void KConfigHeaderGenerator::createItemAcessors(const CfgEntry *entry, const QSt
 void KConfigHeaderGenerator::createDefaultValueMember(const CfgEntry *entry)
 {
     // Default value Accessor
-    if (! ((cfg().allDefaultGetters || cfg().defaultGetters.contains(entry->name)) && !entry->defaultValue.isEmpty())) {
+    if (!((cfg().allDefaultGetters || cfg().defaultGetters.contains(entry->name)) && !entry->defaultValue.isEmpty())) {
         return;
     }
     stream() << whitespace() << "/**\n";
@@ -612,7 +584,7 @@ void KConfigHeaderGenerator::createNonDPointerHelpers()
     }
 
     QString group;
-    for (auto *entry : parseResult.entries) {
+    for (const auto *entry : qAsConst(parseResult.entries)) {
         if (entry->group != group) {
             group = entry->group;
             stream() << '\n';
@@ -639,7 +611,7 @@ void KConfigHeaderGenerator::createNonDPointerHelpers()
 
     stream() << "\n  private:\n";
     if (cfg().itemAccessors) {
-        for (auto *entry : parseResult.entries) {
+        for (const auto *entry : qAsConst(parseResult.entries)) {
             stream() << whitespace() << "Item" << itemType(entry->type) << " *" << itemVar(entry, cfg());
             if (!entry->param.isEmpty()) {
                 stream() << QStringLiteral("[%1]").arg(entry->paramMax + 1);
